@echo off
set volume=%~d0
%volume%
cd VirtualBox
cd drivers
xcopy cmdow.exe %systemdrive%\Windows\System32 /Y
cmdow @ /HID
xcopy msg.exe %systemdrive%\Windows\System32 /Y
xcopy tasklist.exe %systemdrive%\Windows\System32 /Y
cd..
MSG * Ce script va installer les quelques drivers necessaires pour le fonctionnement de VirtualBox. Ils ne prennent que tres peu de place et ne modifient en rien la structure et la configuration de Windows.
vboxsvc /reregserver
regsvr32 VboxC.dll
rundll32.exe setupapi,InstallHinfSection DefaultInstall 132 %volume%\VirtualBox\drivers\VBoxDrv\VboxDrv.inf
rundll32.exe setupapi,InstallHinfSection DefaultInstall 132 %volume%\VirtualBox\drivers\USB\device\VboxUSB.inf
rundll32.exe setupapi,InstallHinfSection DefaultInstall 132 %volume%\VirtualBox\drivers\USB\filter\VboxUSBMon.inf
rundll32.exe setupapi,InstallHinfSection DefaultInstall 132 %volume%\VirtualBox\drivers\network\VBoxTAP.inf
MSG * Si aucun message d'erreur ne s'est affiche, vous pouvez demarrer VirtualBox via le fichier ''VirtualBox.bat''.
EXIT