@echo off

cmdow @ /HID

set volume=%~d0

%volume%
cd VirtualBox
XCOPY /Y /I /S .VirtualBox "%USERPROFILE%"\.VirtualBox

VirtualBox.exe

goto boucle

:boucle

tasklist /FI "IMAGENAME eq VBoxSVC.exe" | find /i "VBoxSVC.exe"

if not errorlevel 1 goto allume
XCOPY /Y /S /I "%USERPROFILE%"\.VirtualBox .VirtualBox
RMDIR /Q /S "%userprofile%\.VirtualBox"
goto fin

:allume
goto boucle

:fin
MSG * Vous pouvez maintenant deconnecter votre disque dur externe via la gestion des peripheriques ( ''Retirer le peripherique en toute securite'' )
EXIT