:AssignNewLetter.cmd
@echo off
color 1F
set volume=%~d0
echo.
set letter=%volume:~0,1%
echo Ce volume a la lettre = %letter% =
set /p NewLetter=Quelle est la nouvelle lettre a attribuer au lecteur ?
echo.
echo Vous avez choisi la lettre : %NewLetter%
echo.
if %NewLetter%=="" exit
if /i %NewLetter%==%letter% goto :sameletter
if exist %NewLetter%: goto :exist
echo rescan > %temp%\drive.log
echo select volume %volume%>> %temp%\drive.log
echo assign letter=%NewLetter%>> %temp%\drive.log
echo exit>> %temp%\drive.log
diskpart -s %temp%\drive.log
del %temp%\drive.log
if exist %NewLetter%: mountvol %volume% /d
@pause
goto :eof
:sameletter
echo Ce lecteur a deja la lettre %letter%
@pause
goto :eof
:exist
echo %NewLetter%: n'est pas libre
@pause